#
# spec file for package perl-Authen-SASL
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Authen-SASL
Name:           perl-Authen-SASL
Version:        2.170.0
Release:        1.3
%define cpan_version 2.1700
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        SASL Authentication framework
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/EH/EHUELS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Digest::HMAC_MD5)
BuildRequires:  perl(Pod::Coverage::TrustPod)
BuildRequires:  perl(Test::Pod)
BuildRequires:  perl(Test::Pod::Coverage)
Requires:       perl(Digest::HMAC_MD5)
Provides:       perl(Authen::SASL) = 2.170.0
Provides:       perl(Authen::SASL::CRAM_MD5) = 2.170.0
Provides:       perl(Authen::SASL::EXTERNAL) = 2.170.0
Provides:       perl(Authen::SASL::Perl) = 2.170.0
Provides:       perl(Authen::SASL::Perl::ANONYMOUS) = 2.170.0
Provides:       perl(Authen::SASL::Perl::CRAM_MD5) = 2.170.0
Provides:       perl(Authen::SASL::Perl::DIGEST_MD5) = 2.170.0
Provides:       perl(Authen::SASL::Perl::EXTERNAL) = 2.170.0
Provides:       perl(Authen::SASL::Perl::GSSAPI) = 2.170.0
Provides:       perl(Authen::SASL::Perl::LOGIN) = 2.170.0
Provides:       perl(Authen::SASL::Perl::PLAIN) = 2.170.0
%define         __perllib_provides /bin/true
Recommends:     perl(GSSAPI)
%{perl_requires}

%description
SASL is a generic mechanism for authentication used by several network
protocols. *Authen::SASL* provides an implementation framework that all
protocols should be able to share.

The framework allows different implementations of the connection class to
be plugged in. At the time of writing there were two such plugins.

* Authen::SASL::Perl

This module implements several mechanisms and is implemented entirely in
Perl.

* Authen::SASL::XS

This module uses the Cyrus SASL C-library (both version 1 and 2 are
supported).

* Authen::SASL::Cyrus

This module is the predecessor to Authen::SASL::XS.

Until version 2.16, Authen::SASL::Cyrus was loaded as an alternative to
Authen::SASL::XS.

By default Authen::SASL tries to load Authen::SASL::XS first, followed by
Authen::SASL::Perl on failure. If you want to change the order or want to
specifically use one implementation only simply do

 use Authen::SASL qw(Perl);

or if you have another plugin module that supports the Authen::SASL API

 use Authen::SASL qw(My::SASL::Plugin);

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc api.txt Changes compat_pl example_pl README
%license LICENSE

%changelog
* Fri Aug 11 2023 Tina Müller <tina.mueller@suse.com>
- Remove perl526.path (not needed anymore)
* Fri Aug 11 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.1700
  see /usr/share/doc/packages/perl-Authen-SASL/Changes
  2.1700  2023-08-09
    [Fixed]
  - Version numbering (released as 2.1700,
    because 2.17 < 2.1401)
  - POD errors
  - Typos
  - Minimum Perl version 5.005 -> 5.6.0
  - Kwalitee errors
  * Accidentally packaged MYMETA.*
  * 'use warnings;' added in all modules
  * Synchronized versions in all modules
  - Out of bounds substr() (RT 85294)
    [Added]
  - README
  - More tests
    [Changed]
  - Release switched from EUMM to D::Z
    [Removed]
  - Authen::SASL::Cyrus is no longer loaded as
    an implementation; Authen::SASL::XS has been
    the successor for more than a decade
* Fri Sep 29 2017 coolo@suse.com
- add perl526.path to build with perl 5.26
* Mon Jun  3 2013 coolo@suse.com
- updated to 2.16
  * SASL.pod: fix typo [Peter Marschall]
  * Perl.pm: avoid warning on "uninitialized value" [Peter Marschall]
* Thu Nov 17 2011 coolo@suse.com
- use original tar
* Mon May 16 2011 vcizek@novell.com
- update to 2.15
  * Makes sure that user callbacks are called [Yann Kerherve]
- license correction
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Apr  4 2010 chris@computersalat.de
- update to 2.1401
  * Add META.yml to release
- cleanup spec
  * sort TAGS
  * update Url
  * fix deps
  - BuildReq perl
  - Build-/Req Digest::MD5, Digest::HMAC_MD5
  * added compat_pl, SIGNATURE to doc
- added perl-macros
* Fri Mar 26 2010 anicka@suse.cz
- update to 2.14
  * Documentation updates
  * Added server API description
  * Bugfixes to LOGIN, PLAIN and DIGEST_MD5
  * Added server support for LOGIN, PLAINaand DIGEST_MD5
  * Compatiblity with Authen::SASL::XS
* Wed Jan 13 2010 anicka@suse.cz
- update to 2.13
  * RT#42191 Only use pass for GSSAPI credentials if it is an
    object of type GSSAPI::Cred
  * RT#675 Authorization with Authen::SASL::Perl::External
  * Call client_new and server_new inside eval so further plugins
    can be tried before failing
  * Prefer to use Authen::SASL::XS over Authen::SASL::Cyrus
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Jul 25 2008 anicka@suse.cz
- update to 2.12
  * GSSAPI implement protocol according to RFC, but by default,
    remain compatible with cyrus sasl lib
  * DIGEST-MD5 implement channel encryption layer
* Thu Jun 19 2008 anicka@suse.cz
- update to 2.11
  * implement securesocket() in the ::Perl set of plugins
  * fix parsing challenges from GnuSASL
  * update tests for DIGEST-MD5
  * New test from Phil Pennock for testing final server response
* Thu Jul 13 2006 anicka@suse.cz
- update to 2.10
  * Added Authen::SASL::Perl::GSSAPI
  * Added error method to Authen::SASL to obtain error
    from last connection
  * bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 mt@suse,de
- update to 2.09
* Fri Aug 13 2004 mjancar@suse.cz
- update to 2.08
* Tue Mar  2 2004 mjancar@suse.cz
- add perl-Digest-HMAC to neededforbuild
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.06
* Wed Oct 22 2003 mjancar@suse.cz
- update to 2.05
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Wed Jun 18 2003 mjancar@suse.cz
- update to 2.04
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Sat Dec 28 2002 prehak@suse.cz
- initial version 2.02 of this package
